[gtk-vnc] src: fix incorrect method names in API docs and inconsistent param names



commit 9766de7ed7e3e40dc450031efc5879f2fd57687b
Author: Daniel P. Berrangé <dan berrange com>
Date:   Wed Apr 7 18:05:17 2021 +0100

    src: fix incorrect method names in API docs and inconsistent param names
    
    Signed-off-by: Daniel P. Berrangé <berrange redhat com>

 src/vncdisplay.c | 34 +++++++++++++++++-----------------
 1 file changed, 17 insertions(+), 17 deletions(-)
---
diff --git a/src/vncdisplay.c b/src/vncdisplay.c
index d9437e9..6e98630 100644
--- a/src/vncdisplay.c
+++ b/src/vncdisplay.c
@@ -3158,9 +3158,9 @@ gboolean vnc_display_set_scaling(VncDisplay *obj,
 
 
 /**
- * vnc_display_force_size:
+ * vnc_display_set_force_size:
  * @obj: (transfer none): the VNC display widget
  * @enabled: TRUE to force the widget size, FALSE otherwise
  *
  * Set whether the widget size will be forced to match the
  * remote desktop size. If the widget size does not match
@@ -3168,10 +3168,10 @@ gboolean vnc_display_set_scaling(VncDisplay *obj,
  * of the remote desktop may be hidden, or black borders
  * may be drawn.
  */
-void vnc_display_set_force_size(VncDisplay *obj, gboolean enabled)
+void vnc_display_set_force_size(VncDisplay *obj, gboolean enable)
 {
     g_return_if_fail (VNC_IS_DISPLAY (obj));
-    obj->priv->force_size = enabled;
+    obj->priv->force_size = enable;
 
     if (obj->priv->fb != NULL) {
         gtk_widget_queue_resize(GTK_WIDGET(obj));
@@ -3180,9 +3180,9 @@ void vnc_display_set_force_size(VncDisplay *obj, gboolean enabled)
 
 
 /**
- * vnc_display_allow_resize:
+ * vnc_display_set_allow_resize:
  * @obj: (transfer none): the VNC display widget
  * @enabled: TRUE to allow the desktop resize, FALSE otherwise
  *
  * Set whether changes in the widget size will be translated
  * into requests to resize the remote desktop. Resizing of
@@ -3190,31 +3190,31 @@ void vnc_display_set_force_size(VncDisplay *obj, gboolean enabled)
  * servers, but when it is, it will avoid the need todo
  * scaling.
  */
-void vnc_display_set_allow_resize(VncDisplay *obj, gboolean enabled)
+void vnc_display_set_allow_resize(VncDisplay *obj, gboolean enable)
 {
     g_return_if_fail (VNC_IS_DISPLAY (obj));
-    obj->priv->allow_resize = enabled;
+    obj->priv->allow_resize = enable;
 
-    if (obj->priv->fb != NULL && enabled) {
+    if (obj->priv->fb != NULL && enable) {
         gtk_widget_queue_resize(GTK_WIDGET(obj));
     }
 }
 
 
 /**
- * vnc_display_smoothing:
+ * vnc_display_set_smoothing:
  * @obj: (transfer none): the VNC display widget
- * @enabled: TRUE to enable smooth scaling, FALSE otherwise
+ * @enable: TRUE to enable smooth scaling, FALSE otherwise
  *
  * Set whether pixels are smoothly interpolated when scaling,
  * to avoid aliasing.
  */
-void vnc_display_set_smoothing(VncDisplay *obj, gboolean enabled)
+void vnc_display_set_smoothing(VncDisplay *obj, gboolean enable)
 {
     int ww, wh;
 
     g_return_if_fail (VNC_IS_DISPLAY (obj));
-    obj->priv->smoothing = enabled;
+    obj->priv->smoothing = enable;
 
     if (obj->priv->fb != NULL) {
         GdkWindow *window = gtk_widget_get_window(GTK_WIDGET(obj));
@@ -3229,19 +3229,19 @@ void vnc_display_set_smoothing(VncDisplay *obj, gboolean enabled)
 
 
 /**
- * vnc_display_keep_aspect_ratio:
+ * vnc_display_set_keep_aspect_ratio:
  * @obj: (transfer none): the VNC display widget
  * @enabled: TRUE to keep aspect ratio, FALSE otherwise
  *
  * Set whether the aspect ratio of the framebuffer is preserved
  * when scaling.
  */
-void vnc_display_set_keep_aspect_ratio(VncDisplay *obj, gboolean enabled)
+void vnc_display_set_keep_aspect_ratio(VncDisplay *obj, gboolean enable)
 {
     int ww, wh;
 
     g_return_if_fail (VNC_IS_DISPLAY (obj));
-    obj->priv->keep_aspect_ratio = enabled;
+    obj->priv->keep_aspect_ratio = enable;
 
     if (obj->priv->fb != NULL) {
         GdkWindow *window = gtk_widget_get_window(GTK_WIDGET(obj));
@@ -3158,9 +3158,9 @@ gboolean vnc_display_set_scaling(VncDisplay *obj,
  * @obj: (transfer none): the VNC display widget
- * @enabled: TRUE to force the widget size, FALSE otherwise
+ * @enable: TRUE to force the widget size, FALSE otherwise
  *
  * Set whether the widget size will be forced to match the
@@ -3180,9 +3180,9 @@ void vnc_display_set_force_size(VncDisplay *obj, gboolean enabled)
  * @obj: (transfer none): the VNC display widget
- * @enabled: TRUE to allow the desktop resize, FALSE otherwise
+ * @enable: TRUE to allow the desktop resize, FALSE otherwise
  *
  * Set whether changes in the widget size will be translated
@@ -3229,19 +3229,19 @@ void vnc_display_set_smoothing(VncDisplay *obj, gboolean enabled)
  * @obj: (transfer none): the VNC display widget
- * @enabled: TRUE to keep aspect ratio, FALSE otherwise
+ * @enable: TRUE to keep aspect ratio, FALSE otherwise
  *
  * Set whether the aspect ratio of the framebuffer is preserved


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]